@@ -1,8 +1,8 @@
 
-__version__ = "0.6"
+__version__ = "0.6.1"
 __version_vcs_info__ = {
     'branch': 'master',
-    'revid': '37d1ea1',
-    'revno': 426}
+    'revid': '280a0e5',
+    'revno': 430}
 __version_user_email__ = "skalkoto@grnet.gr"
 __version_user_name__ = "Nikos Skalkotos"
